@@ -5,7 +5,7 @@ from . import virtualenv
 
 def run_command(command, *options):
     fab.require('deploy_manage_path')
-    run("%s %s %s %s" % (
+    fab.run("%s %s %s %s" % (
         virtualenv._env_path(),
         fab.env.deploy_manage_path,
         command,
